@@ -16,9 +16,9 @@ import argparse
 from azure.storage.blob import ContainerClient
 
 # Local application/library specific imports
-from .mapping.containermap import ContainerMap
-from .mapping.mapreporter import MapReporter
-from .auth.connectionstringutil import ConnectionStringUtil
+from mapping.containermap import ContainerMap
+from mapping.mapreporter import MapReporter
+from auth.connectionstringutil import ConnectionStringUtil
 
 # TAGS
 __author__ = "Matthew Warren"
@@ -30,10 +30,10 @@ __status__ = "Release"
 
 # GLOBALS
 
-CONN_STRING_SAMPLE = "<BlobEndpoint=https://contosostorageaccount.blob.core.windows.net/;QueueEndpoint=https:",
-"//contosostorageaccount.queue.core.windows.net/;FileEndpoint=https://contosostorageaccount.file.",
-"core.windows.net/;TableEndpoint=https://contosostorageaccount.table.core.windows.net/;",
-"SharedAccessSignature=sv=...>"
+CONN_STRING_SAMPLE = "<BlobEndpoint=https://contosostorageaccount.blob.core.windows.net/;QueueEndpoint=https:" \
+    + "//contosostorageaccount.queue.core.windows.net/;FileEndpoint=https://contosostorageaccount.file." \
+    + "core.windows.net/;TableEndpoint=https://contosostorageaccount.table.core.windows.net/;" \
+    + "SharedAccessSignature=sv=...>"
 
 
 class PipelineOperator:
